@@ -4,6 +4,7 @@ use super::*;
 
 pub(super) trait Optionally {
     fn optionally_filter(self, filter: Option<ec2::model::Filter>) -> Self;
+    fn fold_filters(self, filters: Vec<ec2::model::Filter>) -> Self;
 }
 
 macro_rules! impl_optionally {
@@ -15,6 +16,12 @@ macro_rules! impl_optionally {
                     None => self,
                 }
             }
+
+            fn fold_filters(self, filters: Vec<ec2::model::Filter>) -> Self {
+                filters
+                    .into_iter()
+                    .fold(self, |builder, filter| builder.filters(filter))
+            }
         }
     };
 }
@@ -40,4 +47,9 @@ impl Optionally for builders::DescribeNatGateways {
             None => self,
         }
     }
+    fn fold_filters(self, filters: Vec<ec2::model::Filter>) -> Self {
+        filters
+            .into_iter()
+            .fold(self, |builder, filter| builder.filter(filter))
+    }
 }
